[−][src]Struct cursive_async_view::AnimationProgressFrame
This struct contains the content of a single frame for AsyncProgressView with some metadata about the current frame.
Fields
content: StyledStringStylized String which gets printed until the view is ready, or if the creation has failed.
pos: usizeCurrent position of the loading bar.
next_frame_idx: usizeIndex of the next frame to be drawn, useful if you want to interpolate between two states of progress.